@@ -1,5 +1,15 @@
 jomo1cat.MCMCchain <-
-  function(Y_cat, Y_numcat, X=matrix(1,nrow(Y_cat),1), betap=matrix(0,ncol(X),((sum(Y_numcat)-length(Y_numcat)))), covp=diag(1,ncol(betap)), Sp=diag(1,ncol(betap)), nburn=100) {
+  function(Y_cat, Y_numcat, X=matrix(1,nrow(Y_cat),1), betap=matrix(0,ncol(X),((sum(Y_numcat)-length(Y_numcat)))), covp=diag(1,ncol(betap)), Sp=diag(1,ncol(betap)), nburn=100, output=1, out.iter=10) {
+    Ycatsum1<-rep(0,ncol(Y_cat))
+    for (i in 1:ncol(Y_cat)) {
+      if (min(as.numeric(Y_cat[!is.na(Y_cat[,i]),i]))==0) {
+        Y_cat[,i]<-factor(as.numeric(Y_cat[,i])+1)
+        Ycatsum1[i]<-1
+      }
+    }
+    for (i in 1:ncol(X)) {
+      if (is.factor(X[,i])) X[,i]<-as.numeric(X[,i])
+    }
     stopifnot( nrow(betap)==ncol(X), ncol(betap)==((sum(Y_numcat)-length(Y_numcat))),nrow(covp)==ncol(covp), nrow(covp)==ncol(betap), nrow(Sp)==ncol(Sp),nrow(Sp)==nrow(covp))
     betait=matrix(0,nrow(betap),ncol(betap))
     for (i in 1:nrow(betap)) {
@@ -9,7 +19,6 @@ jomo1cat.MCMCchain <-
     for (i in 1:nrow(covp)) {
       for (j in 1:ncol(covp)) covit[i,j]=covp[i,j]
     }    
-    rngflag=0;
     nimp=1;
     colnamycat<-colnames(Y_cat)
     colnamx<-colnames(X)
@@ -26,6 +35,7 @@ jomo1cat.MCMCchain <-
       } 
       h=h+Y_numcat[i]-1
     }
+    if (output!=1) out.iter=nburn+2
     imp=matrix(0,nrow(Y)*(nimp+1),ncol(Y)+ncol(X)+2)
     imp[1:nrow(Y),1:ncol(Y)]=Y
     imp[1:nrow(X), (ncol(Y)+1):(ncol(Y)+ncol(X))]=X
@@ -37,20 +47,26 @@ jomo1cat.MCMCchain <-
     imp[(nrow(X)+1):(2*nrow(X)), (ncol(Y)+ncol(X)+2)]=c(1:nrow(Y))
     betapost<- array(0, dim=c(nrow(betap),ncol(betap),nburn))
     omegapost<- array(0, dim=c(nrow(covp),ncol(covp),nburn))
-    collectimp<- array(0, dim=c(nrow(Y),ncol(covp),nburn))
     meanobs<-colMeans(Yi,na.rm=TRUE)
     for (i in 1:nrow(Yi)) for (j in 1:ncol(Yi)) if (is.na(Yimp[i,j])) Yimp2[i,j]=meanobs[j]
-    .Call("MCMCjomo1mix", Y, Yimp, Yimp2, Y_cat, X,betait,betapost,covit,omegapost, nburn, Sp,Y_numcat, 0, rngflag,collectimp, PACKAGE = "jomo")
+    .Call("MCMCjomo1mix", Y, Yimp, Yimp2, Y_cat, X,betait,betapost,covit,omegapost, nburn, Sp,Y_numcat, 0, out.iter, PACKAGE = "jomo")
     imp[(nrow(Y)+1):(2*nrow(Y)),1:ncol(Y)]=Y_cat
+    for (i in 1:ncol(Y)) {
+      if (Ycatsum1[i]==1) {
+        imp[,i]<-factor(as.numeric(imp[,i])-1)                   
+      }
+    }
     betapostmean<-apply(betapost, c(1,2), mean)
     omegapostmean<-apply(omegapost, c(1,2), mean)
-    cat("The posterior mean of the fixed effects estimates is:\n")
-    print(betapostmean)
-    cat("The posterior covariance matrix is:\n")
-    print(omegapostmean)
+    if (output==1) {
+      cat("The posterior mean of the fixed effects estimates is:\n")
+      print(betapostmean)
+      cat("The posterior covariance matrix is:\n")
+      print(omegapostmean)
+    }
     imp<-data.frame(imp)
     if (is.null(colnamycat)) colnamycat=paste("Y", 1:ncol(Y_cat), sep = "")
     if (is.null(colnamx)) colnamx=paste("X", 1:ncol(X), sep = "")
     colnames(imp)<-c(colnamycat,colnamx,"Imputation","id")
-    return(list("finimp"=imp,"collectimp"=collectimp,"collectbeta"=betapost,"collectomega"=omegapost))
+    return(list("finimp"=imp,"collectbeta"=betapost,"collectomega"=omegapost))
   }
