@@ -1,5 +1,15 @@
 jomo1mix <-
-  function(Y_con, Y_cat, Y_numcat, X=matrix(1,nrow(Y_cat),1), betap=matrix(0,ncol(X),(ncol(Y_con)+(sum(Y_numcat)-length(Y_numcat)))), covp=diag(1,ncol(betap)), Sp=diag(1,ncol(betap)), nburn=100, nbetween=100, nimp=5) {
+  function(Y_con, Y_cat, Y_numcat, X=matrix(1,nrow(Y_cat),1), betap=matrix(0,ncol(X),(ncol(Y_con)+(sum(Y_numcat)-length(Y_numcat)))), covp=diag(1,ncol(betap)), Sp=diag(1,ncol(betap)), nburn=100, nbetween=100, nimp=5, output=1, out.iter=10) {
+    Ycatsum1<-rep(0,ncol(Y_cat))
+    for (i in 1:ncol(Y_cat)) {
+      if (min(as.numeric(Y_cat[!is.na(Y_cat[,i]),i]))==0) {
+        Y_cat[,i]<-factor(as.numeric(Y_cat[,i])+1)
+        Ycatsum1[i]<-1
+      }
+    }
+    for (i in 1:ncol(X)) {
+      if (is.factor(X[,i])) X[,i]<-as.numeric(X[,i])
+    }
     stopifnot(nrow(Y_con)==nrow(X), nrow(betap)==ncol(X), ncol(betap)==(ncol(Y_con)+(sum(Y_numcat)-length(Y_numcat))),nrow(covp)==ncol(covp), nrow(covp)==ncol(betap), nrow(Sp)==ncol(Sp),nrow(Sp)==nrow(covp))
     betait=matrix(0,nrow(betap),ncol(betap))
     for (i in 1:nrow(betap)) {
@@ -9,7 +19,6 @@ jomo1mix <-
     for (i in 1:nrow(covp)) {
       for (j in 1:ncol(covp)) covit[i,j]=covp[i,j]
     }   
-    rngflag=0
     colnamycon<-colnames(Y_con)
     colnamycat<-colnames(Y_cat)
     colnamx<-colnames(X)
@@ -27,6 +36,7 @@ jomo1mix <-
       } 
       h=h+Y_numcat[i]-1
     }
+    if (output!=1) out.iter=nburn+nbetween
     imp=matrix(0,nrow(Y)*(nimp+1),ncol(Y)+ncol(X)+2)
     imp[1:nrow(Y),1:ncol(Y)]=Y
     imp[1:nrow(X), (ncol(Y)+1):(ncol(Y)+ncol(X))]=X
@@ -42,7 +52,7 @@ jomo1mix <-
     opost<-matrix(0,nrow(covp),ncol(covp))
     meanobs<-colMeans(Yi,na.rm=TRUE)
     for (i in 1:nrow(Yi)) for (j in 1:ncol(Yi)) if (is.na(Yimp[i,j])) Yimp2[i,j]=meanobs[j]
-    .Call("jomo1mix", Y, Yimp, Yimp2, Y_cat, X,betait,bpost,covit,opost, nburn, Sp,Y_numcat, ncol(Y_con),rngflag, PACKAGE = "jomo")
+    .Call("jomo1mix", Y, Yimp, Yimp2, Y_cat, X,betait,bpost,covit,opost, nburn, Sp,Y_numcat, ncol(Y_con),out.iter, PACKAGE = "jomo")
    
     #betapost[,,1]=bpost
     #omegapost[,,1]=opost
@@ -50,26 +60,33 @@ jomo1mix <-
     opost<-matrix(0,nrow(covp),ncol(covp))
     imp[(nrow(Y)+1):(2*nrow(Y)),1:ncol(Y_con)]=Yimp2[,1:ncol(Y_con)]
     imp[(nrow(Y)+1):(2*nrow(Y)),(ncol(Y_con)+1):ncol(Y)]=Y_cat
-    cat("First imputation registered.", "\n")
+    if (output==1) cat("First imputation registered.", "\n")
     for (i in 2:nimp) {
       imp[(i*nrow(X)+1):((i+1)*nrow(X)),(ncol(Y)+1):(ncol(Y)+ncol(X))]=X
       imp[(i*nrow(X)+1):((i+1)*nrow(X)), (ncol(Y)+ncol(X)+1)]=i
       imp[(i*nrow(X)+1):((i+1)*nrow(X)), (ncol(Y)+ncol(X)+2)]=c(1:nrow(Y))
-        .Call("jomo1mix", Y, Yimp, Yimp2, Y_cat, X,betait,bpost,covit, opost, nbetween, Sp, Y_numcat, ncol(Y_con),rngflag, PACKAGE = "jomo") 
+        .Call("jomo1mix", Y, Yimp, Yimp2, Y_cat, X,betait,bpost,covit, opost, nbetween, Sp, Y_numcat, ncol(Y_con),out.iter, PACKAGE = "jomo") 
       betapost[,,(i-1)]=bpost
       omegapost[,,(i-1)]=opost
       bpost<-matrix(0,nrow(betap),ncol(betap))
       opost<-matrix(0,nrow(covp),ncol(covp))
       imp[(i*nrow(X)+1):((i+1)*nrow(X)),1:ncol(Y_con)]=Yimp2[,1:ncol(Y_con)]
       imp[(i*nrow(X)+1):((i+1)*nrow(X)),(ncol(Y_con)+1):ncol(Y)]=Y_cat
-      cat("Imputation number ", i, "registered", "\n")
+      if (output==1) cat("Imputation number ", i, "registered", "\n")
+    }
+    for (i in 1:ncol(Y_cat)) {
+      if (Ycatsum1[i]==1) {
+        imp[,(ncol(Y_con)+i)]<-factor(as.numeric(imp[,(ncol(Y_con)+i)])-1)                   
+      }
     }
     betapostmean<-apply(betapost, c(1,2), mean)
     omegapostmean<-apply(omegapost, c(1,2), mean)
-    cat("The posterior mean of the fixed effects estimates is:\n")
-    print(betapostmean)
-    cat("The posterior covariance matrix is:\n")
-    print(omegapostmean)
+    if (output==1) {
+      cat("The posterior mean of the fixed effects estimates is:\n")
+      print(betapostmean)
+      cat("The posterior covariance matrix is:\n")
+      print(omegapostmean)
+    }
     imp<-data.frame(imp)
     if (is.null(colnamycat)) colnamycat=paste("Ycat", 1:ncol(Y_cat), sep = "")
     if (is.null(colnamycon)) colnamycon=paste("Ycon", 1:ncol(Y_con), sep = "")
