@@ -1,4 +1,10 @@
-jomo1rancon<- function(Y, X=matrix(1,nrow(Y),1), Z=matrix(1,nrow(Y),1), clus, betap=matrix(0,ncol(X),ncol(Y)), up=matrix(0,nrow(unique(clus)),ncol(Z)*ncol(Y)), covp=diag(1,ncol(Y)), covu=diag(1,ncol(Y)*ncol(Z)), Sp=diag(1,ncol(Y)), Sup=diag(1,ncol(Y)*ncol(Z)), nburn=100, nbetween=100, nimp=5) {
+jomo1rancon<- function(Y, X=matrix(1,nrow(Y),1), Z=matrix(1,nrow(Y),1), clus, betap=matrix(0,ncol(X),ncol(Y)), up=matrix(0,nrow(unique(clus)),ncol(Z)*ncol(Y)), covp=diag(1,ncol(Y)), covu=diag(1,ncol(Y)*ncol(Z)), Sp=diag(1,ncol(Y)), Sup=diag(1,ncol(Y)*ncol(Z)), nburn=100, nbetween=100, nimp=5, output=1, out.iter=10) {
+  for (i in 1:ncol(X)) {
+    if (is.factor(X[,i])) X[,i]<-as.numeric(X[,i])
+  }
+  for (i in 1:ncol(Z)) {
+    if (is.factor(Z[,i])) Z[,i]<-as.numeric(Z[,i])
+  }
   stopifnot(nrow(Y)==nrow(clus),nrow(Y)==nrow(X), nrow(betap)==ncol(X), ncol(betap)==ncol(Y),nrow(covp)==ncol(covp), nrow(covp)==ncol(Y), nrow(Sp)==ncol(Sp),nrow(Sp)==nrow(covp), nrow(Z)==nrow(Y), ncol(covu)==ncol(up), ncol(up)==ncol(Z)*ncol(Y))
   betait=matrix(0,nrow(betap),ncol(betap))
   for (i in 1:nrow(betap)) {
@@ -16,7 +22,6 @@ jomo1rancon<- function(Y, X=matrix(1,nrow(Y),1), Z=matrix(1,nrow(Y),1), clus, be
   for (i in 1:nrow(covu)) {
     for (j in 1:ncol(covu)) covuit[i,j]=covu[i,j]
   }   
-  rngflag=0
   colnamy<-colnames(Y)
   colnamx<-colnames(X)
   colnamz<-colnames(Z)
@@ -24,6 +29,7 @@ jomo1rancon<- function(Y, X=matrix(1,nrow(Y),1), Z=matrix(1,nrow(Y),1), clus, be
   X<-as.matrix(X,nrow(X),ncol(X))
   Z<-as.matrix(Z,nrow(Z),ncol(Z))
   clus<-as.matrix(clus,nrow(clus),ncol(clus))
+  if (output!=1) out.iter=nburn+nbetween
   imp=matrix(0,nrow(Y)*(nimp+1),ncol(Y)+ncol(X)+ncol(Z)+3)
   imp[1:nrow(Y),1:ncol(Y)]=Y
   imp[1:nrow(X), (ncol(Y)+1):(ncol(Y)+ncol(X))]=X
@@ -49,7 +55,7 @@ jomo1rancon<- function(Y, X=matrix(1,nrow(Y),1), Z=matrix(1,nrow(Y),1), clus, be
   varobs<-apply(Y,2,sd,na.rm=TRUE)
   for (i in 1:nrow(Y)) for (j in 1:ncol(Y)) if (is.na(Yimp[i,j])) Yimp[i,j]=meanobs[j]
   #for (i in 1:nrow(Y)) for (j in 1:ncol(Y)) if (is.na(Yimp[i,j])) Yimp[i,j]=rnorm(1,mean=meanobs[j], sd=0.01)
-  .Call("jomo1rancon", Y, Yimp, Yimp2, X, Z, clus, betait, uit, bpost, upost, covit, opost, covuit, cpost, nburn, Sp, Sup,rngflag, PACKAGE = "jomo")
+  .Call("jomo1rancon", Y, Yimp, Yimp2, X, Z, clus, betait, uit, bpost, upost, covit, opost, covuit, cpost, nburn, Sp, Sup,out.iter, PACKAGE = "jomo")
   #betapost[,,1]=bpost
   #upostall[,,1]=upost
   #omegapost[,,1]=opost
@@ -60,7 +66,7 @@ jomo1rancon<- function(Y, X=matrix(1,nrow(Y),1), Z=matrix(1,nrow(Y),1), clus, be
   cpost<-matrix(0,nrow(covu),ncol(covu))
   imp[(nrow(Y)+1):(2*nrow(Y)),1:ncol(Y)]=Yimp2
   Yimp=Yimp2
-  cat("First imputation registered.", "\n")
+  if (output==1) cat("First imputation registered.", "\n")
   for (i in 2:nimp) {
     Yimp2=matrix(0, nrow(Y),ncol(Y))
     imp[(i*nrow(X)+1):((i+1)*nrow(X)),(ncol(Y)+1):(ncol(Y)+ncol(X))]=X
@@ -68,7 +74,7 @@ jomo1rancon<- function(Y, X=matrix(1,nrow(Y),1), Z=matrix(1,nrow(Y),1), clus, be
     imp[(i*nrow(clus)+1):((i+1)*nrow(clus)), (ncol(Y)+ncol(X)+ncol(Z)+1)]=clus
     imp[(i*nrow(Z)+1):((i+1)*nrow(Z)), (ncol(Y)+ncol(X)+ncol(Z)+2)]=c(1:nrow(Y))
     imp[(i*nrow(Z)+1):((i+1)*nrow(Z)), (ncol(Y)+ncol(X)+ncol(Z)+3)]=i
-    .Call("jomo1rancon", Y, Yimp, Yimp2, X, Z, clus, betait, uit, bpost, upost, covit,opost, covuit,cpost, nbetween, Sp, Sup,rngflag, PACKAGE = "jomo")
+    .Call("jomo1rancon", Y, Yimp, Yimp2, X, Z, clus, betait, uit, bpost, upost, covit,opost, covuit,cpost, nbetween, Sp, Sup,out.iter, PACKAGE = "jomo")
     betapost[,,(i-1)]=bpost
     upostall[,,(i-1)]=upost
     omegapost[,,(i-1)]=opost
@@ -79,20 +85,22 @@ jomo1rancon<- function(Y, X=matrix(1,nrow(Y),1), Z=matrix(1,nrow(Y),1), clus, be
     cpost<-matrix(0,nrow(covu),ncol(covu))
     imp[(i*nrow(Y)+1):((i+1)*nrow(Y)),1:ncol(Y)]=Yimp2
     Yimp=Yimp2
-    cat("Imputation number ", i, "registered", "\n")
+    if (output==1) cat("Imputation number ", i, "registered", "\n")
   }
   betapostmean<-apply(betapost, c(1,2), mean)
   upostmean<-apply(upostall, c(1,2), mean)
   omegapostmean<-apply(omegapost, c(1,2), mean)
   covupostmean<-apply(covupost, c(1,2), mean)
-  cat("The posterior mean of the fixed effects estimates is:\n")
-  print(betapostmean)
-  cat("The posterior mean of the random effects estimates is:\n")
-  print(upostmean)
-  cat("The posterior mean of the level 1 covariance matrix is:\n")
-  print(omegapostmean)
-  cat("The posterior mean of the level 2 covariance matrix is:\n")
-  print(covupostmean)
+  if (output==1) {
+    cat("The posterior mean of the fixed effects estimates is:\n")
+    print(betapostmean)
+    cat("The posterior mean of the random effects estimates is:\n")
+    print(upostmean)
+    cat("The posterior mean of the level 1 covariance matrices is:\n")
+    print(omegapostmean)
+    cat("The posterior mean of the level 2 covariance matrix is:\n")
+    print(covupostmean)
+  }
   imp<-data.frame(imp)
   if (is.null(colnamy)) colnamy=paste("Y", 1:ncol(Y), sep = "")
   if (is.null(colnamz)) colnamz=paste("Z", 1:ncol(Z), sep = "")
