@@ -1,5 +1,11 @@
 jomo1ranconhr.MCMCchain <-
-  function(Y, X=matrix(1,nrow(Y),1), Z=matrix(1,nrow(Y),1), clus, betap=matrix(0,ncol(X),ncol(Y)), up=matrix(0,nrow(unique(clus)),ncol(Z)*ncol(Y)), covp=matrix(diag(1,ncol(Y)),nrow(unique(clus))*ncol(Y),ncol(Y),2), covu=diag(1,ncol(Y)*ncol(Z)), Sp=diag(1,ncol(Y)), Sup=diag(1,ncol(Y)*ncol(Z)), nburn=100, a=ncol(Y),meth="random") {
+  function(Y, X=matrix(1,nrow(Y),1), Z=matrix(1,nrow(Y),1), clus, betap=matrix(0,ncol(X),ncol(Y)), up=matrix(0,nrow(unique(clus)),ncol(Z)*ncol(Y)), covp=matrix(diag(1,ncol(Y)),nrow(unique(clus))*ncol(Y),ncol(Y),2), covu=diag(1,ncol(Y)*ncol(Z)), Sp=diag(1,ncol(Y)), Sup=diag(1,ncol(Y)*ncol(Z)), nburn=100, a=ncol(Y),meth="random", output=1, out.iter=10) {
+    for (i in 1:ncol(X)) {
+      if (is.factor(X[,i])) X[,i]<-as.numeric(X[,i])
+    }
+    for (i in 1:ncol(Z)) {
+      if (is.factor(Z[,i])) Z[,i]<-as.numeric(Z[,i])
+    }
     stopifnot((meth=="fixed"|meth=="random"),nrow(Y)==nrow(clus),nrow(Y)==nrow(X), nrow(betap)==ncol(X), ncol(betap)==ncol(Y),nrow(covp)==nrow(up)*ncol(covp), nrow(covp)==nrow(up)*ncol(Y), nrow(Sp)==ncol(Sp),nrow(covp)==nrow(up)*nrow(Sp), nrow(Z)==nrow(Y), ncol(covu)==ncol(up), ncol(up)==ncol(Z)*ncol(Y))
     betait=matrix(0,nrow(betap),ncol(betap))
     for (i in 1:nrow(betap)) {
@@ -19,7 +25,6 @@ jomo1ranconhr.MCMCchain <-
     }   
     ait=0
     ait=a
-    rngflag=0
     nimp=1
     colnamy<-colnames(Y)
     colnamx<-colnames(X)
@@ -28,6 +33,7 @@ jomo1ranconhr.MCMCchain <-
     X<-as.matrix(X,nrow(X),ncol(X))
     Z<-as.matrix(Z,nrow(Z),ncol(Z))
     clus<-as.matrix(clus,nrow(clus),ncol(clus))
+    if (output!=1) out.iter=nburn+2
     imp=matrix(0,nrow(Y)*(nimp+1),ncol(Y)+ncol(X)+ncol(Z)+3)
     imp[1:nrow(Y),1:ncol(Y)]=Y
     imp[1:nrow(X), (ncol(Y)+1):(ncol(Y)+ncol(X))]=X
@@ -43,7 +49,6 @@ jomo1ranconhr.MCMCchain <-
     imp[(nrow(X)+1):(2*nrow(X)), (ncol(Y)+ncol(X)+ncol(Z)+3)]=1
     betapost<- array(0, dim=c(nrow(betap),ncol(betap),nburn))
     omegapost<- array(0, dim=c(nrow(covp),ncol(covp),nburn))
-    collectimp<- array(0, dim=c(nrow(Y),ncol(covp),nburn))
     upostall<-array(0, dim=c(nrow(up),ncol(up),nburn))
     covupost<- array(0, dim=c(nrow(covu),ncol(covu),nburn))
     meanobs<-colMeans(Y,na.rm=TRUE)
@@ -51,10 +56,10 @@ jomo1ranconhr.MCMCchain <-
     for (i in 1:nrow(Y)) for (j in 1:ncol(Y)) if (is.na(Yimp[i,j])) Yimp[i,j]=meanobs[j]
     #for (i in 1:nrow(Y)) for (j in 1:ncol(Y)) if (is.na(Yimp[i,j])) Yimp[i,j]=rnorm(1,mean=meanobs[j], sd=0.01)
     if (meth=="fixed") {
-      .Call("MCMCjomo1ranconhf", Y, Yimp, Yimp2, X, Z, clus, betait, uit, betapost, upostall, covit,omegapost, covuit,covupost, nburn, Sp, Sup,rngflag=0, collectimp, PACKAGE = "jomo") 
+      .Call("MCMCjomo1ranconhf", Y, Yimp, Yimp2, X, Z, clus, betait, uit, betapost, upostall, covit,omegapost, covuit,covupost, nburn, Sp, Sup,out.iter,  PACKAGE = "jomo") 
     }
     if (meth=="random") {
-      .Call("MCMCjomo1ranconhr", Y, Yimp, Yimp2, X, Z, clus, betait, uit, betapost, upostall, covit,omegapost, covuit,covupost, nburn, Sp, Sup, ait,rngflag=0,collectimp, PACKAGE = "jomo") 
+      .Call("MCMCjomo1ranconhr", Y, Yimp, Yimp2, X, Z, clus, betait, uit, betapost, upostall, covit,omegapost, covuit,covupost, nburn, Sp, Sup, ait,out.iter, PACKAGE = "jomo") 
     }
     imp[(nrow(Y)+1):(2*nrow(Y)),1:ncol(Y)]=Yimp2
     Yimp=Yimp2
@@ -62,18 +67,20 @@ jomo1ranconhr.MCMCchain <-
     upostmean<-apply(upostall, c(1,2), mean)
     omegapostmean<-apply(omegapost, c(1,2), mean)
     covupostmean<-apply(covupost, c(1,2), mean)
-    cat("The posterior mean of the fixed effects estimates is:\n")
-    print(betapostmean)
-    cat("The posterior mean of the random effects estimates is:\n")
-    print(upostmean)
-    cat("The posterior mean of the level 1 covariance matrices is:\n")
-    print(omegapostmean)
-    cat("The posterior mean of the level 2 covariance matrix is:\n")
-    print(covupostmean)
+    if (output==1) {
+      cat("The posterior mean of the fixed effects estimates is:\n")
+      print(betapostmean)
+      cat("The posterior mean of the random effects estimates is:\n")
+      print(upostmean)
+      cat("The posterior mean of the level 1 covariance matrices is:\n")
+      print(omegapostmean)
+      cat("The posterior mean of the level 2 covariance matrix is:\n")
+      print(covupostmean)
+    }
     imp<-data.frame(imp)
     if (is.null(colnamy)) colnamy=paste("Y", 1:ncol(Y), sep = "")
     if (is.null(colnamz)) colnamz=paste("Z", 1:ncol(Z), sep = "")
     if (is.null(colnamx)) colnamx=paste("X", 1:ncol(X), sep = "")
     colnames(imp)<-c(colnamy,colnamx,colnamz,"clus","id","Imputation")
-    return(list("finimp"=imp,"collectimp"=collectimp,"collectbeta"=betapost,"collectomega"=omegapost,"collectu"=upostall, "collectcovu"=covupost))
+    return(list("finimp"=imp,"collectbeta"=betapost,"collectomega"=omegapost,"collectu"=upostall, "collectcovu"=covupost))
   }
