@@ -9,7 +9,7 @@
 #include<Rinternals.h>
 #include<Rmath.h>
 
-SEXP MCMCjomo1ranmixhr(SEXP Y, SEXP Yimp, SEXP Yimp2, SEXP Yimpcat, SEXP X, SEXP Z, SEXP clus, SEXP beta, SEXP u, SEXP betapost, SEXP upost, SEXP omega,SEXP omegapost, SEXP covu, SEXP covupost, SEXP nstep, SEXP Sp, SEXP Sup, SEXP Y_numcat, SEXP num_con, SEXP a_start, SEXP flagrng, SEXP collectimp){
+SEXP MCMCjomo1ranmixhr(SEXP Y, SEXP Yimp, SEXP Yimp2, SEXP Yimpcat, SEXP X, SEXP Z, SEXP clus, SEXP beta, SEXP u, SEXP betapost, SEXP upost, SEXP omega,SEXP omegapost, SEXP covu, SEXP covupost, SEXP nstep, SEXP Sp, SEXP Sup, SEXP Y_numcat, SEXP num_con, SEXP a_start, SEXP flagrng){
 int indic=0,i,j,k, IY,JY, IX, JX, Io, Jo, Ib, Jb, ns, nmiss=0,t, countm=0, counto=0, countmm=0, countmo=0,countoo=0, jj, tt, kk, ncon,ncat, pos,flag=0,nmaxx,h;
 int Iu, Ju, IZ, JZ, nj,c, fl,currncat;
 SEXP RdimY, RdimX, Rdimo, Rdimb, RdimZ, Rdimu;
@@ -66,7 +66,6 @@ ncat=length(Y_numcat);
 a_start=PROTECT(coerceVector(a_start,REALSXP));
 a=REAL(a_start)[0];
 nj=Iu;
-collectimp=PROTECT(coerceVector(collectimp,REALSXP));
 
 /*Allocating memory for C objects in R*/
 
@@ -273,7 +272,7 @@ for (i=0;i<ns;i++) {
 
 				if (REAL(Y)[t+(ncon+j)*IY]==INTEGER(Y_numcat)[j]) {
 					while ((flag==0)&(kk<10000)) {
-						r8vec_multinormal_sample((INTEGER(Y_numcat)[j]-1), mumiss,omegamm, newbeta,mu4,fl);
+						r8vec_multinormal_sample((INTEGER(Y_numcat)[j]-1), mumiss,omegamm, newbeta,mu4,0);
 						maxim=maxvec((INTEGER(Y_numcat)[j]-1),newbeta);
 						if (maxim<0) {						
 							for (k=0;k<(INTEGER(Y_numcat)[j]-1);k++) imp[t+(k+pos)*IY]=newbeta[k];
@@ -285,7 +284,7 @@ for (i=0;i<ns;i++) {
 				}
 				else {
 					while ((flag==0)&(kk<10000)) {
-						r8vec_multinormal_sample((INTEGER(Y_numcat)[j]-1), mumiss,omegamm, newbeta,mu4,fl);
+						r8vec_multinormal_sample((INTEGER(Y_numcat)[j]-1), mumiss,omegamm, newbeta,mu4,0);
 						maxim=argmaxvec((INTEGER(Y_numcat)[j]-1),newbeta);
 						maxim2=maxvec((INTEGER(Y_numcat)[j]-1),newbeta);
 						if (((maxim+1)==REAL(Y)[t+(ncon+j)*IY])&(maxim2>0)) {
@@ -337,7 +336,7 @@ for (i=0;i<ns;i++) {
 	for (jj=1;jj<JX*JY;jj++) for (tt=0;tt<jj;tt++) invomega2[jj+JX*JY*tt]=invomega2[tt+JX*JY*jj];
 	r8mat_mm_new(JY*JX,JY*JX,1,invomega2,sumxy,mu);
 	r8mat_pofac(JY * JX,invomega2,help3,6);
-	r8vec_multinormal_sample(JY*JX, mu,help3, REAL(beta),newbeta,fl);
+	r8vec_multinormal_sample(JY*JX, mu,help3, REAL(beta),newbeta,0);
 	
 	for (j=0;j<Ib;j++) {
 		for (t=0;t<Jb;t++) {
@@ -385,7 +384,7 @@ for (i=0;i<ns;i++) {
 		for (jj=1;jj<JZ*JY;jj++) for (tt=0;tt<jj;tt++) invomega3[jj+JZ*JY*tt]=invomega3[tt+JZ*JY*jj];
 		r8mat_mm_new(JY*JZ,JY*JZ,1,invomega3,sumzy,mu2);
 		r8mat_pofac(JY * JZ,invomega3,help5,9); 
-		r8vec_multinormal_sample(JY*JZ, mu2,help5,newu, incrzy,fl);
+		r8vec_multinormal_sample(JY*JZ, mu2,help5,newu, incrzy,0);
 		for (t=0;t<JY;t++) for (k=0;k<JZ;k++) REAL(u)[c+nj*(k+t*JZ)] = newu[k+t*JZ];
 		
 	}
@@ -409,7 +408,7 @@ for (i=0;i<ns;i++) {
 	r8mat_pofac(JY*JZ,mu3,help5,10);
 	r8mat_poinv(JY*JZ, help5, invomega3);
 	for (jj=1;jj<(JY*JZ);jj++) for (tt=0;tt<jj;tt++) invomega3[jj+(JZ*JY)*tt]=invomega3[tt+(JZ*JY)*jj];
-	wishart_sample(JY*JZ,(nj+JY*JZ),invomega3,newomega2, help5,sumzi,incrzz,mu3,fl);
+	wishart_sample(JY*JZ,(nj+JY*JZ),invomega3,newomega2, help5,sumzi,incrzz,mu3,0);
 	
 	r8mat_pofac(JY * JZ,newomega2, help5,11);
 	r8mat_poinv(JY * JZ, help5,invomega3);
@@ -449,14 +448,14 @@ for (i=0;i<ns;i++) {
 	r8mat_poinv(JY, help7, Gammastar);
 	for (jj=1;jj<JY;jj++) for (tt=0;tt<jj;tt++) Gammastar[jj+JY*tt]=Gammastar[tt+JY*jj];
 
-	wishart_sample(JY,(nj*a+gamma),Gammastar,invA,help, omegaoo,omegaom,omegamm,fl);
+	wishart_sample(JY,(nj*a+gamma),Gammastar,invA,help, omegaoo,omegaom,omegamm,0);
 
 		u_m=newton_raphson(u_new,precision, dx,eta,JY,nj,allinvomega,invomega,invA,help,help2);
 	if (u_m!=-9999) {
 		con=-log_f_u(eta, u_m, JY, nj, allinvomega, invomega,  invA,  help,  help2);
 		deriv2=derive2_f_u(dx,eta, u_m, JY, nj, allinvomega, invomega,  invA,  help,  help2,con);
 		lambda=sqrt(-5/(4*deriv2));
-		u_prop=lambda*t_sample(4,fl)+u_m;
+		u_prop=lambda*t_sample(4,0)+u_m;
 		con2=exp(log_f_u(eta, u_prop, JY, nj, allinvomega, invomega, invA,help,help2)-log_f_u(eta, u_new, JY, nj, allinvomega, invomega, invA,help,help2))*h_u(u_new,u_m,lambda)/h_u(u_prop,u_m,lambda);
 		if ((( double ) unif_rand ( ) )<r8_min(1,con2)) u_new=u_prop;
 		a=u_new;
@@ -466,7 +465,7 @@ for (i=0;i<ns;i++) {
 		con=-log_f_u(eta, u_m, JY, nj, allinvomega, invomega,  invA,  help,  help2);
 		deriv2=derive2_log_f_u(dx,eta, u_m, JY, nj, allinvomega, invomega,  invA,  help,  help2);
 		lambda=sqrt(-5/(4*deriv2));
-		u_prop=lambda*t_sample(4,fl)+u_m;
+		u_prop=lambda*t_sample(4,0)+u_m;
 		con2=exp(log_f_u(eta, u_prop, JY, nj, allinvomega, invomega, invA,help,help2)-log_f_u(eta, u_new, JY, nj, allinvomega, invomega, invA,help,help2))*h_u(u_new,u_m,lambda)/h_u(u_prop,u_m,lambda);
 		if ((( double ) unif_rand ( ) )<r8_min(1,con2)) u_new=u_prop;
 		a=u_new;
@@ -516,7 +515,7 @@ for (i=0;i<ns;i++) {
 				}
 				kk=0;
 				while ((flag==0)&(kk<100)) {
-					newomega[j+JY*k]=r8_normal_sample(meanom,sdom,fl);
+					newomega[j+JY*k]=r8_normal_sample(meanom,sdom,0);
 					newomega[k+JY*j]=newomega[j+JY*k];
 					flag=checkposdef(JY,newomega,help,help6);
 					kk++;
@@ -612,7 +611,7 @@ for (i=0;i<ns;i++) {
 			r8mat_divide(nmiss,nmiss,-1,omegadrawmiss);
 			r8mat_add(nmiss,nmiss,omegamm,omegadrawmiss);
 			r8mat_pofac(nmiss,omegadrawmiss,help9,16+1000*j);
-			r8vec_multinormal_sample(nmiss,mumiss,help9,Ymiss,help6,fl);
+			r8vec_multinormal_sample(nmiss,mumiss,help9,Ymiss,help6,0);
 			countm=0;
 			for (k=0;k<JY;k++) {
 				if (ISNAN(REAL(Yimp)[j+k*IY])) {
@@ -630,12 +629,7 @@ for (i=0;i<ns;i++) {
 		}
 	
 	}
-	for (j=0;j<IY;j++) {
-			for (t=0;t<JY;t++) {
-				REAL(collectimp)[j+IY*t+i*IY*JY]=imp[j+IY*t];
-			}
-		}
-	if ((i+1)%10==0) Rprintf("Iteration %d completed\n",i+1);
+	if ((i+1)%fl==0) Rprintf("Iteration %d completed\n",i+1);
 }
 for(i=0;i<IY;i++)  {
 	for(j=0;j<JY;j++)  {
@@ -659,6 +653,6 @@ for(i=0;i<IY;i++)  {
 }
 REAL(a_start)[0]=a;
 PutRNGstate();
-UNPROTECT(29);
+UNPROTECT(28);
 return R_NilValue;
 }
